@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2014-2019 Red Hat, Inc.
+ * Copyright (c) 2014-2023 Red Hat, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,14 +27,13 @@ public final class ServiceLocatorFactory
     /**
      * Load an instance of XMvn service.
      * 
-     * @param role interface class identifying requested service
      * @return instance of XMvn service, never {@code null}.
      */
     public ServiceLocator createServiceLocator()
     {
         try
         {
-            return (ServiceLocator) Class.forName( "org.fedoraproject.xmvn.locator.impl.DefaultServiceLocator" ).newInstance();
+            return (ServiceLocator) Class.forName( "org.fedoraproject.xmvn.locator.impl.DefaultServiceLocator" ).getConstructor().newInstance();
         }
         catch ( ReflectiveOperationException e )
         {
