@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2016-2019 Red Hat, Inc.
+ * Copyright (c) 2016-2023 Red Hat, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,7 +15,7 @@
  */
 package org.fedoraproject.xmvn.test;
 
-import org.junit.Before;
+import org.junit.jupiter.api.BeforeEach;
 
 import org.fedoraproject.xmvn.config.Configurator;
 import org.fedoraproject.xmvn.locator.impl.DefaultServiceLocator;
@@ -25,9 +25,9 @@ import org.fedoraproject.xmvn.locator.impl.DefaultServiceLocator;
  */
 public class AbstractTest
 {
-    private DefaultServiceLocator locator;
+    protected DefaultServiceLocator locator;
 
-    @Before
+    @BeforeEach
     public void configureServiceLocator()
     {
         locator = new DefaultServiceLocator();
