@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2013-2019 Red Hat, Inc.
+ * Copyright (c) 2013-2023 Red Hat, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,15 +16,30 @@
 package org.fedoraproject.xmvn.test;
 
 import org.fedoraproject.xmvn.config.Configuration;
+import org.fedoraproject.xmvn.config.Configurator;
 import org.fedoraproject.xmvn.config.Repository;
 import org.fedoraproject.xmvn.config.impl.DefaultConfigurator;
+import org.fedoraproject.xmvn.locator.ServiceLocator;
 
 /**
  * @author Mikolaj Izdebski
  */
 public class TestConfigurator
-    extends DefaultConfigurator
+    implements Configurator
 {
+    private final Configurator delegate;
+
+    public TestConfigurator( ServiceLocator locator )
+    {
+        delegate = new DefaultConfigurator( locator );
+    }
+
+    @Override
+    public Configuration getDefaultConfiguration()
+    {
+        return delegate.getDefaultConfiguration();
+    }
+
     @Override
     public synchronized Configuration getConfiguration()
     {
